@@ -1,6 +1,6 @@
 # Java skeleton for Bison                           -*- autoconf -*-
 
-# Copyright (C) 2007-2015, 2018-2020 Free Software Foundation, Inc.
+# Copyright (C) 2007-2015, 2018-2021 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,8 +53,9 @@ b4_use_push_for_pull_if([
 # allows them to be defined either in parse() when doing pull parsing,
 # or as class instance variable when doing push parsing.
 m4_define([b4_define_state],[[
-    /* Lookahead and lookahead in internal form.  */
+    /* Lookahead token kind.  */
     int yychar = YYEMPTY_;
+    /* Lookahead symbol kind.  */
     SymbolKind yytoken = null;
 
     /* State.  */
@@ -77,7 +78,7 @@ m4_define([b4_define_state],[[
 
 ]b4_output_begin([b4_parser_file_name])[
 ]b4_copyright([Skeleton implementation for Bison LALR(1) parsers in Java],
-              [2007-2015, 2018-2020])[
+              [2007-2015, 2018-2021])[
 ]b4_disclaimer[
 ]b4_percent_define_ifdef([api.package], [package b4_percent_define_get([api.package]);[
 ]])[
@@ -1078,17 +1079,18 @@ b4_dollar_popdef[]dnl
 
   /* YYTRANSLATE_(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
      as returned by yylex, with out-of-bounds checking.  */
-  private static final SymbolKind yytranslate_ (int t)
+  private static final SymbolKind yytranslate_(int t)
 ]b4_api_token_raw_if(dnl
 [[  {
     return SymbolKind.get(t);
   }
 ]],
 [[  {
-    int code_max_ = ]b4_code_max[;
+    // Last valid token kind.
+    int code_max = ]b4_code_max[;
     if (t <= 0)
       return ]b4_symbol(0, kind)[;
-    else if (t <= code_max_)
+    else if (t <= code_max)
       return SymbolKind.get(yytranslate_table_[t]);
     else
       return ]b4_symbol(2, kind)[;
