@@ -29,7 +29,7 @@ struct gl_multiple_nodes
 #define MULTIPLE_NODES_MAGIC  (void *) -1
 
 /* Returns the position of the given node in the tree.  */
-static size_t
+static size_t _GL_ATTRIBUTE_PURE
 node_position (gl_list_node_t node)
 {
   size_t position = 0;
@@ -55,7 +55,7 @@ node_position (gl_list_node_t node)
 }
 
 /* Compares two nodes by their position in the tree.  */
-static int
+static int _GL_ATTRIBUTE_PURE
 compare_by_position (const void *x1, const void *x2)
 {
   gl_list_node_t node1 = (gl_list_node_t) x1;
@@ -68,7 +68,7 @@ compare_by_position (const void *x1, const void *x2)
 }
 
 /* Compares a node's position in the tree with a given threshold.  */
-static bool
+static bool _GL_ATTRIBUTE_PURE
 compare_position_threshold (const void *x, const void *threshold)
 {
   gl_list_node_t node = (gl_list_node_t) x;
