@@ -1,6 +1,6 @@
 /* Data definitions for internal representation of Bison's input.
 
-   Copyright (C) 1984, 1986, 1989, 1992, 2001-2007, 2009-2015, 2018-2020
+   Copyright (C) 1984, 1986, 1989, 1992, 2001-2007, 2009-2015, 2018-2021
    Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
@@ -103,8 +103,6 @@
 
 # include "system.h"
 
-# include <unicodeio.h>
-
 # include "location.h"
 # include "symtab.h"
 
@@ -217,25 +215,6 @@ typedef struct
 extern rule *rules;
 extern rule_number nrules;
 
-/* Fallback in case we can't print "•".  */
-static inline long
-print_dot_fallback (unsigned int code _GL_UNUSED,
-                    const char *msg _GL_UNUSED,
-                    void *callback_arg)
-{
-  FILE *out = (FILE *) callback_arg;
-  putc ('.', out);
-  return -1;
-}
-
-/* Print "•", the symbol used to represent a point in an item (aka, a
-   dotted rule).  */
-static inline void
-print_dot (FILE *out)
-{
-  unicode_to_mb (0x2022, fwrite_success_callback, print_dot_fallback, out);
-}
-
 /* Get the rule associated to this item.  ITEM points inside RITEM.  */
 static inline rule const *
 item_rule (item_number const *item)
